### R code from vignette source 'RenextGuide.Rnw'

###################################################
### code chunk number 1: options
###################################################
options(prompt = "> ", continue = " ", width = 80)
L <- installed.packages()
ind <- !is.na(match(L[, "Package"], "Renext"))
Renext.Version <- L[ind, "Version"]


###################################################
### code chunk number 2: RenextGuide.Rnw:414-417
###################################################
library(Renext)
data(Brest)
names(Brest)


###################################################
### code chunk number 3: RenextGuide.Rnw:421-423
###################################################
head(Brest$OTdata, n = 4)
str(Brest$OTinfo)


###################################################
### code chunk number 4: <
###################################################
End <- Brest$OTinfo$end; Start <- Brest$OTinfo$start
Dur <- as.numeric(difftime(End,  Start, units = "days"))/365.25
Dur
Dur-as.numeric(Brest$OTinfo$effDuration) 


###################################################
### code chunk number 5: RenplotBrest
###################################################
class(Brest)
plot(Brest)


###################################################
### code chunk number 6: missing
###################################################
head(Brest$OTmissing, n = 4)


###################################################
### code chunk number 7: labelgaronneMAX
###################################################
data(Garonne)
names(Garonne)
Garonne$MAXinfo
head(Garonne$MAXdata, n = 4)


###################################################
### code chunk number 8: RenplotGaronne
###################################################
plot(Garonne)


###################################################
### code chunk number 9: exppBrest
###################################################
expplot(x = Brest$OTdata$Surge, main = "expplot for \"Brest\"")


###################################################
### code chunk number 10: weibpBrest
###################################################
weibplot(x = Brest$OTdata$Surge-30, main = "weibplot for \"Brest\" (surge - 30)")


###################################################
### code chunk number 11: ExpPlot
###################################################
library(evd); set.seed(136)
X <- rgumbel(400); X <- X[X > 0.6]           ## X is truncated Gumbel
n <- length(X); 
Z <- sort(X); F <- (1:n)/(n+1)               ## distribution function
y.exp <- -log(1-F); y.gum <- -log(-log(F))   
plot(Z, y.exp, col = "red3", main = "exponential plot")


###################################################
### code chunk number 12: GumPlot
###################################################
plot(Z, y.gum, col = "SteelBlue3", main = "Gumbel plot")


###################################################
### code chunk number 13: spGaronne
###################################################
data(Garonne)
plot(Flow ~ date, data = Garonne$OTdata, type = "h", main = "Flows > 2500 m3/s")


###################################################
### code chunk number 14: RenextGuide.Rnw:675-676
###################################################
 subset(Garonne$OTdata, date >= as.POSIXct("1945-01-01") & date <= as.POSIXct("1950-01-01"))


###################################################
### code chunk number 15: gdGaronne
###################################################
gof.date(date = Garonne$OTdata$date)


###################################################
### code chunk number 16: ieGaronne
###################################################
ie <- interevt(date = Garonne$OTdata$date)
names(ie)
d <- ie$interevt$duration
expplot(d, main = "Exponential plot for interevents")
bt <- gofExp.test(d) 
bt


###################################################
### code chunk number 17: gdBrest
###################################################
gof.Brest  <- gof.date(date = Brest$OTdata$date, skip = Brest$OTmissing,
                       start = Brest$OTinfo$start, end = Brest$OTinfo$end)
print(names(gof.Brest))


###################################################
### code chunk number 18: gdBrest
###################################################
head(gof.Brest$noskip, n = 2)


###################################################
### code chunk number 19: gdBrest2
###################################################
gof.Brest2  <- gof.date(date = Brest$OTdata$date, 
                        skip = Brest$OTmissing, plot.type = "omit",
                        start = Brest$OTinfo$start, end = Brest$OTinfo$end)


###################################################
### code chunk number 20: bp40
###################################################
data(Brest.years); data(Brest.years.missing)
bp40 <- barplotRenouv(data = Brest.years, threshold = 40,
           na.block = Brest.years.missing, main = "threshold = 40 cm")


###################################################
### code chunk number 21: bp50
###################################################
bp50 <- barplotRenouv(data = Brest.years, threshold = 50,
           na.block = Brest.years.missing, main = "threshold = 50 cm")


###################################################
### code chunk number 22: RenextGuide.Rnw:951-953
###################################################
bp40$tests
bp50$tests


###################################################
### code chunk number 23: RenextGuide.Rnw:958-959
###################################################
bp50$freq


###################################################
### code chunk number 24: feGaronne
###################################################
fit.exp <- fRenouv(x.OT = Garonne$OTdata$Flow,
                   sumw.BOT = 65,
                   threshold = 2500,
                   distname.y = "exponential",
                   main = "exponential")
fit.exp$estimate


###################################################
### code chunk number 25: namefitexp
###################################################
names(fit.exp)


###################################################
### code chunk number 26: fwGaronne
###################################################
fit.weibull <- fRenouv(x.OT = Garonne$OTdata$Flow,
                        sumw.BOT = 65,
                        threshold = 2500,
                        distname.y = "weibull",
                        main = "Weibull")
fit.weibull$estimate
fit.weibull$sigma


###################################################
### code chunk number 27: feGaronneH
###################################################
fit.exp.H <- fRenouv(x.OT = Garonne$OTdata$Flow,
                      sumw.BOT = 65,
                      z.H = Garonne$MAXdata$Flow,
                      block.H = Garonne$MAXdata$block,
                      w.BH = Garonne$MAXinfo$duration,
                      distname.y = "exponential",
                      threshold = 2500,
                      conf.pct = c(70, 95),
                      prob.max = 0.99995,
                      pred.period = c(10,100,1000),
                      main = "Garonne data, \"exponential\" with MAXdata")


###################################################
### code chunk number 28: fwGaronneH
###################################################
fit.weib.H <- fRenouv(x.OT = Garonne$OTdata$Flow,
                      sumw.BOT = 65,
                      z.H = Garonne$MAXdata$Flow,
                      block.H = Garonne$MAXdata$block,
                      w.BH = Garonne$MAXinfo$duration,
                      distname.y = "weibull",
                      threshold = 2500,
                      conf.pct = c(70, 95),
                      prob.max = 0.99995,
                      pred.period = c(10,100,1000),
                      main = "Garonne data, \"Weibull\" with MAXdata")


###################################################
### code chunk number 29: nonorth
###################################################
fit.exp.H$corr


###################################################
### code chunk number 30: fixweibGaronneH
###################################################
fit.weib.fixed.H <- 
  fRenouv(x.OT = Garonne$OTdata$Flow,
          sumw.BOT = 65,
          z.H = Garonne$MAXdata$Flow,
          block.H = Garonne$MAXdata$block,
          w.BH = Garonne$MAXinfo$duration,
          distname.y = "weibull",
          threshold = 2500,
          fixed.par.y = list(shape = 1.2),
          start.par.y = list(scale = 2000),
          trace = 0,
          main = "Garonne data, \"Weibull\" with MAXdata and fixed shape")


###################################################
### code chunk number 31: nonorth
###################################################
fit.weib.fixed.H$estimate


###################################################
### code chunk number 32: fixSLTWGaronneH
###################################################
fit.SLTW.H <- 
  fRenouv(x.OT = Garonne$OTdata$Flow,
          sumw.BOT = 65,
          z.H = Garonne$MAXdata$Flow,
          block.H = Garonne$MAXdata$block,
          w.BH = Garonne$MAXinfo$duration,
          distname.y = "SLTW",
          threshold = 2500,
          fixed.par.y = list(delta = 2000, shape = 1.2),
          start.par.y = list(scale = 2000),
          main = "Garonne data, \"SLTW\" with MAXdata, delta and shape fixed")


###################################################
### code chunk number 33: nonorth
###################################################
fit.SLTW.H$cov


